; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "blocking"
command = $F,x
time = 3

[Command]
name = "blocking" ;Same name as above (buttons in opposite order)
command = x,$F
time = 3

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------

[Command]
name = "AI0"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI1"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI2"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI3"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI4"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI5"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI6"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI7"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI8"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI9"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI10"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI11"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI12"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI13"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI14"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI15"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI16"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI17"
command = a,B,c,x,y,z,s,B,D,F,U,a,b,c,x,y,z,s,s
time = 0
[Command]
name = "AI18"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI19"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI20"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI21"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI22"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI23"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI24"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI25"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI26"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI27"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI28"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI29"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI30"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI31"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI32"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI33"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI34"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI35"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI36"
command = z,z,z,z,z,z,a,a,a,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI37"
command = z,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,z,z,z
time = 0
[Command]
name = "AI38"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z
time = 0
[Command]
name = "AI39"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI40"
command = z,z,z,z,a,a,a,z,z,z,z,a,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI41"
command = z,z,z,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z,z
time = 0
[Command]
name = "AI42"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI43"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,a,a,z
time = 0
[Command]
name = "AI44"
command = z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,a,a,a,z
time = 0
[Command]
name = "AI45"
command = z,z,z,z,z,z,a,a,z,z,z,z,z,a,a,a,a,z,z
time = 0
[Command]
name = "AI46"
command = z,z,z,z,z,z,z,z,a,a,a,a,a,a,z,z,z,z,z
time = 0
[Command]
name = "AI47"
command = z,z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI48"
command = z,z,z,z,z,a,a,a,z,z,z,a,a,a,z,z,a,z,a
time = 0
[Command]
name = "AI49"
command = z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z,z
time = 0
[Command]
name = "AI50"
command = z,z,z,a,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI51"
command = z,z,z,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z,z,a
time = 0
[Command]
name = "AI52"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,b
time = 0
[Command]
name = "AI53"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,a,a,z,c
time = 0
[Command]
name = "AI54"
command = z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,a,a,a,z,x
time = 0
[Command]
name = "AI55"
command = z,z,z,z,z,z,a,a,z,z,z,z,z,a,a,a,a,z,z,y
time = 0
[Command]
name = "AI56"
command = z,z,z,z,z,z,z,z,a,a,a,a,a,a,z,z,z,z,z,z
time = 0
[Command]
name = "AI57"
command = z,z,z,a,a,a,a,z,z,z,z,z,z,z,z,z,z,z,z,z,a
time = 0
[Command]
name = "AI58"
command = z,z,z,z,z,a,a,a,z,z,z,a,a,a,z,z,a,z,a,z,b
time = 0
[Command]
name = "AI59"
command = z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z,z,z,c
time = 0
[Command]
name = "AI60"
command = z,z,z,a,a,z,z,z,z,z,z,z,z,z,a,a,z,z,z,z,x
time = 0

[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
;X}bVEJt[EEbp[iQ[WxPj
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "SmashKFUpper"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "TripleKFPalm"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = stateno != 250
trigger2 = stateno != 251
trigger2 = movecontact
trigger3 = !var(59)
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking
trigger4 = var(59)
trigger4 = stateno = 1310 || stateno = 1330 ;From blocking
trigger4 = time>0
var(1) = 1

;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "FF_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [600,640]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "FF_a"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [600,640]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
;Jt[Rij
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "FF_b"
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = [600,640]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
;Jt[EEbp[
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "upper_xy"
triggerall = power >= 330
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
;Jt[EEbp[ij
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "upper_x"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
;Jt[EEbp[ij
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "upper_y"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCF_xy"
triggerall = power >= 330
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCF_x"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCF_y"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Blow (1/3 super bar)
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCB_xy"
triggerall = power >= 330
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCB_x"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCB_y"
triggerall = statetype != A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kick Combo
;ALbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCF_a"
triggerall = statetype != A
triggerall = stateno != 240
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kick Combo
;ALbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 251
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "QCF_b"
triggerall = statetype != A
triggerall = stateno != 240
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = statetype != A
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = statetype != A
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================

;---------------------------------------------------------------------------
;High Kung Fu Blocking (High)
[State -1, High Kung Fu Blocking High]
type = ChangeState
value = 1300
triggerall = command = "blocking"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = time > 0

;---------------------------------------------------------------------------
;High Kung Fu Blocking (Low)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1320
triggerall = command = "blocking"
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = time > 0

;---------------------------------------------------------------------------
;High Kung Fu Blocking (Air)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1340
triggerall = command = "blocking"
triggerall = command != "holdup"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = A
trigger2 = stateno = 1350
trigger2 = time > 0

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != A
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = statetype != A
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && movecontact
trigger3 = (stateno = 230) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = statetype != A
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && movecontact
trigger3 = (stateno = 230) && movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype != A
triggerall = stateno != 250
triggerall = stateno != 251
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && movecontact
trigger3 = (stateno = 230) && movecontact

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "start"
triggerall = statetype != A
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "x"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "y"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "a"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59)<=1
triggerall = command = "b"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;////////////////////////////////////////////////////////////////
;AI
;////////////////////////////////////////////////////////////////

;---------------------------------------------------------------------------
;낵肢܂I
;---------------------------------------------------------------------------

[State -1, Taunt]
type = ChangeState
value = 195
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = roundstate = 2 && Alive
triggerall = var(59)=[1,4]
triggerall = statetype != A
trigger1 = !var(58)
trigger1 = ctrl

;---------------------------------------------------------------------------
;namew΍
;---------------------------------------------------------------------------

;`
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = var(59) && roundstate = 2 && Alive
triggerall = !inguarddist
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = ctrl
trigger1 = EnemyNear,Name = "Dan Hibiki"
trigger1 = EnemyNear,AutHorName = "adamskie"
trigger1 = (EnemyNear,stateno = [3400,3440]) || (EnemyNear,stateno = [3500,3530])
trigger2 = EnemyNear,Name = "cvsdan"
trigger2 = EnemyNear,AutHorName = "Warusaki3"
trigger2 = (EnemyNear,stateno = [3500,3505])
trigger3 = EnemyNear,Name = "Dan Hibiki"
trigger3 = EnemyNear,AutHorName = "Tatsu"
trigger3 = EnemyNear,stateno = 3600 || EnemyNear,stateno = 3700 || EnemyNear,stateno = 3705
trigger4 = EnemyNear,Name = "Dan Hibiki"
trigger4 = EnemyNear,AutHorName = "Phantom.of.the.Server"
trigger4 = EnemyNear,stateno = 3300 || (EnemyNear,stateno = [4100,4101])

;---------------------------------------------------------------------------
;R{
;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = power >= 1000
triggerall = stateno!=[1050,1099]
trigger1 = hitdefattr = SC, NA, SA, HA
trigger1 = stateno != [3000,3050)
trigger1 = prevstateno != 400 && prevstateno!=430
trigger1 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=[1,5])
trigger1 = (stateno != 250) || (stateno=250 && AnimElemTime(21)>=0)
trigger1 = stateno != 200
trigger1 = stateno != 400
trigger1 = random<50
trigger1 = Enemynear,vel Y>=0
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = (stateno = 240) || (stateno=250 && AnimElemTime(21)>=0)
trigger2 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=[1,5])
trigger3 = hitdefattr = SC, NA, SA, HA
trigger3 = Enemynear,statetype=A
trigger3 = stateno = [410,430]
trigger3 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger3 = p2bodydist X=[5,15]

;Smash Kung Fu Upper (uses one super bar)
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = power >= 1000
trigger1 = ctrl
trigger1 = Enemynear,vel X>0
trigger1 = Enemynear,movetype=H
trigger1 = p2bodydist X=[10,25]
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger2 = p2bodydist X=[0,15]
trigger2 = p2bodydist Y=[-60,10]
trigger2 = stateno=3000 && Animelem >=15
trigger2 = Enemynear,statetype!=A || (p2bodydist X=[0,3])

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = power >= 330
triggerall = var(1)
trigger1 = Enemynear,vel X>0
trigger1 = Enemynear,movetype=H
trigger1 = p2bodydist X=[10,20]
trigger1 = p2bodydist Y=[-60,10]
trigger2 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger2 = Enemynear,statetype!=A
trigger2 = p2bodydist X=[10,20]
trigger2 = frontedgebodydist>=180
trigger3 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger3 = Enemynear,statetype!=A
trigger3 = p2bodydist X=[0,20]

;---------------------------------------------------------------------------
;Kick Combo
;LbNR{
[State -1, Kick Combo]
type = ChangeState
value = 250
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = stateno != 240
triggerall = power>=1750
trigger1 = var(1)
trigger1 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger1 = Enemynear,statetype!=A
trigger1 = p2bodydist X=[12,30]

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
trigger1 = (stateno = 200) && movecontact
trigger2 = (stateno = 230) && movecontact

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)
trigger1 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger1 = Enemynear,statetype!=A
trigger1 = p2bodydist X=[30,80]
trigger1 = frontedgebodydist<180

;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = power >= 330
triggerall = var(1)
triggerall = Enemynear,statetype!=C
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = Enemynear,statetype=A
trigger1 = Enemynear,movetype=H && Enemynear,stateno!=[120,155]
trigger1 = p2bodydist X=[15,50]
trigger1 = p2bodydist Y=[-100,-20]
trigger1 = power >= 2500
trigger2 = p2bodydist X=[10,20]
trigger2 = p2bodydist Y=[-100,40]
trigger2 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger2 = random<500
trigger2 = var(59)<=2
trigger2 = stateno!=200
trigger2 = stateno!=400
trigger3 = power >= 2350
trigger3 = Enemynear,statetype=A
trigger3 = p2bodydist X=[10,20]
trigger3 = p2bodydist Y=[-100,40]
trigger3 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger4 = power >= 2350
trigger4 = Enemynear,statetype=A
trigger4 = p2bodydist X=[0,20]
trigger4 = p2bodydist Y=[-100,-20]
trigger4 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)

;---------------------------------------------------------------------------
;Kung Fu Knee
;Jt[R
[State -1, Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = var(1)
triggerall = Enemynear,statetype!=C
trigger1 = Enemynear,statetype!=A
trigger1 = p2bodydist X=[8,20]
trigger1 = p2bodydist Y=[-100,40]
trigger1 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger1 = power<=330

;---------------------------------------------------------------------------
;Kung Fu Knee
;Jt[R
[State -1, Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = var(1)
triggerall = Enemynear,statetype!=C
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = Enemynear,statetype=A
trigger1 = Enemynear,movetype=H && Enemynear,stateno!=[120,155]
trigger1 = p2bodydist X=[15,50]
trigger1 = p2bodydist Y=[-100,-20]
trigger2 = Enemynear,statetype=A
trigger2 = p2bodydist X=[8,25]
trigger2 = p2bodydist Y=[-100,40]
trigger2 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger2 = random<500
trigger2 = var(59)<=2
trigger2 = stateno!=200
trigger2 = stateno!=400
trigger2 = power<=330
trigger3 = p2bodydist X=[0,20]
trigger3 = p2bodydist Y=[-100,40]
trigger3 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger3 = stateno!=200
trigger3 = stateno!=400
trigger4 = Enemynear,statetype=A
trigger4 = p2bodydist X=[10,20]
trigger4 = p2bodydist Y=[-100,40]
trigger4 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger5 = Enemynear,statetype=A
trigger5 = p2bodydist X=[0,20]
trigger5 = p2bodydist Y=[-100,-20]
trigger5 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = var(1)
trigger1 = Enemynear,vel X>0
trigger1 = Enemynear,statetype=A
trigger1 = Enemynear,movetype=H && Enemynear,stateno!=[120,155]
trigger1 = p2bodydist X=[1,40]
trigger1 = p2bodydist Y=[-60,10]
trigger2 = ctrl
trigger2 = Enemynear,vel Y>=0
trigger2 = Enemynear,statetype=A
trigger2 = Enemynear,movetype=H && Enemynear,stateno!=[120,155]
trigger2 = p2bodydist X=[0,20]
trigger2 = p2bodydist Y=[-100,10]
trigger3 = ctrl
trigger3 = Enemynear,vel Y>=0
trigger3 = Enemynear,statetype=A
trigger3 = Enemynear,movetype=H && Enemynear,stateno!=[120,155]
trigger3 = p2bodydist X=[-10,10]
trigger3 = p2bodydist Y=[-100,10]
trigger3 = Enemynear,backedgebodydist<=10

;---------------------------------------------------------------------------

;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = var(1) ;Use combo condition (above)
trigger1 = (var(59)<=2 && movehit) || (var(59)>=3 && movehit=1)
trigger1 = Enemynear,statetype!=A
trigger1 = p2bodydist X=[30,80]

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = var(1)
triggerall = p2bodydist X=[0,60]
trigger1 = random<100
trigger1 = ishelper || numhelper>=2
trigger1 = moveguarded
trigger1 = Enemynear,statetype=C
trigger1 = numhelper(65531)
trigger1 = helper(65531),stateno=400
trigger1 = helper(65531),moveguarded
trigger2 = random<100
trigger2 = ishelper || numhelper>=2
trigger2 = moveguarded
trigger2 = Enemynear,statetype=C
trigger2 = numhelper(65532)
trigger2 = helper(65532),stateno=400
trigger2 = helper(65532),moveguarded
trigger3 = random<100
trigger3 = ishelper || numhelper>=2
trigger3 = moveguarded
trigger3 = Enemynear,statetype=C
trigger3 = numhelper(65533)
trigger3 = helper(65533),stateno=400
trigger3 = helper(65533),moveguarded
trigger4 = random<100
trigger4 = ishelper || numhelper>=2
trigger4 = moveguarded
trigger4 = Enemynear,statetype=C
trigger4 = numhelper(65534)
trigger4 = helper(65534),stateno=400
trigger4 = helper(65534),moveguarded

;---------------------------------------------------------------------------
;ʏs
;---------------------------------------------------------------------------

;High Kung Fu Blocking (High)
[State -1, High Kung Fu Blocking High]
type = ChangeState
value = 1300
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = ctrl || (stateno=111 && time>0)
triggerall = inguarddist
triggerall = Enemynear,movetype=A
trigger1 = var(59)=2 && life>(lifemax/4)
trigger1 = p2bodydist X = [-40,70]
trigger1 = Enemynear,hitdefattr=SA,AA
trigger1 = (Enemynear,time=[15,60]) || (time>=60 && Enemynear,time=[10,15])
trigger1 = random<=100
trigger2 = var(59)=2 && life>(lifemax/4)
trigger2 = p2bodydist X = [-40,30]
trigger2 = !Enemynear,hitdefattr
trigger2 = Enemynear,statetype!=C
trigger2 = (Enemynear,time=[15,60]) || (time>=60 && Enemynear,time=[10,15])
trigger2 = random<=100
trigger3 = (var(59)=3 && life>(lifemax/4)) || (var(59)=2 && life<=(lifemax/4))
trigger3 = p2bodydist X = [-40,70]
trigger3 = Enemynear,hitdefattr=SA,AA
trigger3 = (Enemynear,time=[10,45]) || (time>=60 && Enemynear,time=[5,10])
trigger3 = random<=100
trigger4 = (var(59)=3 && life>(lifemax/4)) || (var(59)=2 && life<=(lifemax/4))
trigger4 = p2bodydist X = [-40,30]
trigger4 = !Enemynear,hitdefattr
trigger4 = Enemynear,statetype!=C
trigger4 = (Enemynear,time=[10,45]) || (time>=60 && Enemynear,time=[5,10])
trigger4 = random<=100
trigger5 = var(59)=3 && life<=(lifemax/4)
trigger5 = p2bodydist X = [-40,70]
trigger5 = Enemynear,hitdefattr=SA,AA
trigger5 = (Enemynear,time=[5,30]) || (time>=30 && Enemynear,time=[0,5])
trigger5 = random<=100
trigger6 = var(59)=3 && life<=(lifemax/4)
trigger6 = p2bodydist X = [-40,30]
trigger6 = !Enemynear,hitdefattr
trigger6 = Enemynear,statetype!=C
trigger6 = (Enemynear,time=[5,30]) || (time>=30 && Enemynear,time=[0,5])
trigger6 = random<=100
trigger7 = var(59)>=4
trigger7 = p2bodydist X = [-40,70]
trigger7 = Enemynear,hitdefattr=SA,AA
trigger7 = Enemynear,time=[0,5]
trigger7 = random<=100
trigger8 = var(59)>=4
trigger8 = p2bodydist X = [-40,30]
trigger8 = !Enemynear,hitdefattr
trigger8 = Enemynear,statetype!=C
trigger8 = Enemynear,time=[0,5]
trigger8 = random<=100

;High Kung Fu Blocking (Low)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1320
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = ctrl || (stateno=111 && time>0)
triggerall = inguarddist
triggerall = Enemynear,movetype=A
trigger1 = var(59)=2 && life>(lifemax/4)
trigger1 = p2bodydist X = [-40,70]
trigger1 = Enemynear,hitdefattr=C,AA
trigger1 = (Enemynear,time=[15,60]) || (time>=60 && Enemynear,time=[10,15])
trigger1 = random<=100
trigger2 = var(59)=2 && life>(lifemax/4)
trigger2 = p2bodydist X = [-40,30]
trigger2 = !Enemynear,hitdefattr
trigger2 = Enemynear,statetype=C
trigger2 = (Enemynear,time=[15,60]) || (time>=60 && Enemynear,time=[10,15])
trigger2 = random<=100
trigger3 = (var(59)=3 && life>(lifemax/4)) || (var(59)=2 && life<=(lifemax/4))
trigger3 = p2bodydist X = [-40,70]
trigger3 = Enemynear,hitdefattr=C,AA
trigger3 = (Enemynear,time=[10,45]) || (time>=60 && Enemynear,time=[5,10])
trigger3 = random<=100
trigger4 = (var(59)=3 && life>(lifemax/4)) || (var(59)=2 && life<=(lifemax/4))
trigger4 = p2bodydist X = [-40,30]
trigger4 = !Enemynear,hitdefattr
trigger4 = Enemynear,statetype=C
trigger4 = (Enemynear,time=[10,45]) || (time>=60 && Enemynear,time=[5,10])
trigger4 = random<=100
trigger5 = var(59)=3 && life<=(lifemax/4)
trigger5 = p2bodydist X = [-40,70]
trigger5 = Enemynear,hitdefattr=C,AA
trigger5 = (Enemynear,time=[5,30]) || (time>=30 && Enemynear,time=[0,5])
trigger5 = random<=100
trigger6 = var(59)=3 && life<=(lifemax/4)
trigger6 = p2bodydist X = [-40,30]
trigger6 = !Enemynear,hitdefattr
trigger6 = Enemynear,statetype=C
trigger6 = (Enemynear,time=[5,30]) || (time>=30 && Enemynear,time=[0,5])
trigger6 = random<=100
trigger7 = var(59)>=4
trigger7 = p2bodydist X = [-40,70]
trigger7 = Enemynear,hitdefattr=C,AA
trigger7 = Enemynear,time=[0,5]
trigger7 = random<=100
trigger8 = var(59)>=4
trigger8 = p2bodydist X = [-40,30]
trigger8 = !Enemynear,hitdefattr
trigger8 = Enemynear,statetype=C
trigger8 = Enemynear,time=[0,5]
trigger8 = random<=100

;High Kung Fu Blocking (Air)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1340
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = A
triggerall = ctrl
triggerall = inguarddist
triggerall = Enemynear,movetype=A
triggerall = Enemynear,hitdefattr=A,AA
trigger1 = var(59)=2 && life>(lifemax/4)
trigger1 = p2bodydist X = [-30,30]
trigger1 = (Enemynear,time=[15,60]) || (time>=60 && Enemynear,time=[10,15])
trigger1 = random<=100
trigger3 = (var(59)=3 && life>(lifemax/4)) || (var(59)=2 && life<=(lifemax/4))
trigger3 = p2bodydist X = [-30,30]
trigger3 = (Enemynear,time=[10,45]) || (time>=60 && Enemynear,time=[5,10])
trigger3 = random<=100
trigger5 = var(59)=3 && life<=(lifemax/4)
trigger5 = p2bodydist X = [-30,30]
trigger5 = (Enemynear,time=[5,30]) || (time>=30 && Enemynear,time=[0,5])
trigger5 = random<=100
trigger7 = var(59)>=4
trigger7 = p2bodydist X = [-30,30]
trigger7 = Enemynear,time=[0,5]
trigger7 = random<=100

;K[h
[State -3, S guard]
type = ChangeState
value = 130
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = var(59)>=3 || Enemynear,time>20 || (random<100 && Enemynear,time=[0,20]) || (time>=15 && vel X<=0)
triggerall = inguarddist || ((Enemynear,time<30 || Enemynear,hitdefattr=SA,AA) && Enemynear,movetype=A && p2bodydist X=[-30,10])
triggerall = ctrl || (stateno=111&&time>0)
triggerall = stateno!=[120,155]
triggerall = !EnemyNear,HitDefAttr = ,NT,ST,HT
Trigger1 = EnemyNear,HitDefAttr = S,AA && Enemynear,time>=15
Trigger2 = EnemyNear,HitDefAttr = A,AA|| EnemyNear,HitDefAttr = SA,AP
Trigger3 = !EnemyNear,HitDefAttr = C,AA,AP
Trigger3 = EnemyNear,statetype=S && Enemynear,time>=15
Trigger4 = !EnemyNear,HitDefAttr = C,AA,AP
Trigger4 = EnemyNear,statetype=A

;݃K[h
[State -3, C guard]
type = ChangeState
value = 131
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = var(59)>=3 || Enemynear,time>20 || (random<100 && Enemynear,time=[0,20]) || (time>=15 && vel X<=0)
triggerall = inguarddist || ((Enemynear,time<30 || Enemynear,hitdefattr=SC,AA) && Enemynear,movetype=A && p2bodydist X=[-30,10])
triggerall = ctrl || (stateno=111&&time>0)
triggerall = stateno!=[120,155]
triggerall = !EnemyNear,HitDefAttr = ,NT,ST,HT
Trigger1 = EnemyNear,HitDefAttr = S,AA && Enemynear,time<15
Trigger2 = EnemyNear,HitDefAttr = C,AA,AP
Trigger3 = !EnemyNear,HitDefAttr = SA,AA,AP
Trigger3 = EnemyNear,statetype=S && Enemynear,time<15
Trigger4 = !EnemyNear,HitDefAttr = SA,AA,AP
Trigger4 = EnemyNear,statetype=C

;󒆃K[h
[State -3, A guard]
type = ChangeState
value = 132
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = A
triggerall = var(59)>=2 || random>900
triggerall = ctrl
trigger1 = InGuardDist
Trigger2 = Abs(P2Dist X) < 60
Trigger2 = EnemyNear,HitDefAttr = ,AA,AP || Enemynear,movetype=A && Enemynear,time<=30
trigger3 = var(39) || Enemynear,numproj
trigger3 = p2bodydist X>60
trigger3 = Facing!=Enemynear,Facing

;---------------------------------------------------------------------------

;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = var(59)>=4 || (var(59)=3 && life<=(lifemax/4) && Enemynear,time>=15) || Enemynear,time>=30 || time>=30 || random<20 || (stateno=111 && time>=15) || (prevstateno=[5000,5250])
triggerall = Enemynear,statetype!=L
triggerall = prevstateno!=800
triggerall = p2bodydist X < 3
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger1 = random<333

;---------------------------------------------------------------------------

;Light Kung Fu Upper
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = Enemynear,statetype!=L
triggerall = Enemynear,statetype=A
trigger1 = !inguarddist || (var(59)<=2 && random<50)
trigger1 = ctrl
trigger1 = Enemynear,vel Y>=0
trigger1 = ishelper || Enemynear,movetype!=A
trigger1 = p2bodydist X=[0,20]
trigger1 = p2bodydist Y=[-100,10]
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = time>0
trigger2 = p2bodydist X=[0,15]
trigger2 = Enemynear,animtime>=10

;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = p2bodydist X<=50
triggerall = p2bodydist X>10
triggerall = !inguarddist
trigger1 = var(59)<=4 || (var(59)>=4 && !numhelper)
trigger1 = random<=50
trigger1 = ctrl || stateno=111
trigger1 = Enemynear,movetype!=H
trigger1 = Enemynear,statetype=S || Enemynear,statetype=C
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = Enemynear,statetype=A
trigger2 = time>0
trigger2 = p2bodydist X=[0,30]
trigger2 = Enemynear,animtime>=7

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = Enemynear,statetype!=L
trigger1 = p2bodydist X=[0,30]
trigger1 = stateno = 1310 || stateno = 1330
trigger1 = time>0
trigger1 = Enemynear,animtime>=3
trigger1 = Enemynear,statetype!=C

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN-1
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = Enemynear,statetype!=A
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = p2bodydist X=[20,45]
trigger1 = p2bodydist Y=[-10,5]
trigger1 = random<70 || (random<=500 && prevstateno=[120,155])
trigger2 = ctrl || (stateno=111&&time>0)
trigger2 = p2bodydist X=[45,55]
trigger2 = p2bodydist Y=[-10,5]
trigger2 = random<30
trigger3 = ctrl || (stateno=111&&time>0)
trigger3 = abs(Enemynear,pos X - pos X)=[20,35]
trigger3 = random<20

;---------------------------------------------------------------------------

;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = Enemynear,statetype!=L
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = p2bodydist X=[15,35]
trigger1 = p2bodydist Y=[-10,5]
trigger1 = random<80 || (random<=500 && prevstateno=[120,155])
trigger1 = !inguarddist || (!Enemynear,hitdefattr=SCA,AA)
trigger2 = ctrl || (stateno=111&&time>0)
trigger2 = p2bodydist X=[0,10]
trigger2 = p2bodydist Y=[-10,5]
trigger2 = (Enemynear,movetype=I && random<333) || Enemynear,movetype=H
trigger2 = !inguarddist || (!Enemynear,hitdefattr=SCA,AA)
trigger3 = stateno = 400
trigger3 = movecontact
trigger3 = p2bodydist X<=15
trigger4 = ctrl || (stateno=111&&time>0)
trigger4 = !inguarddist
trigger4 = abs(Enemynear,pos X - pos X)<20
trigger4 = random<40
trigger5 = ctrl || (stateno=111&&time>0)
trigger5 = !inguarddist
trigger5 = p2bodydist X=[0,20]
trigger5 = p2bodydist Y=[-30,0]
trigger5 = Enemynear,vel Y>0
trigger6 = p2bodydist X=[0,30]
trigger6 = stateno = 1310 || stateno = 1330
trigger6 = time>0
trigger6 = Enemynear,animtime>=3

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN-2
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = Enemynear,statetype!=L
triggerall = Enemynear,statetype!=A
trigger1 = (stateno = 400) || (stateno = 430)
trigger1 = movecontact
trigger1 = p2bodydist X<=38

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype != A
triggerall = !inguarddist || (var(59)<=2 && random<50) || facing=facing
triggerall = Enemynear,statetype!=L
triggerall = Enemynear,movetype=A
trigger1 = ctrl || (stateno=111&&time>0)
trigger1 = p2bodydist X=[30,90]
trigger1 = p2bodydist Y=[-10,5]
trigger1 = random<100
trigger2 = ctrl || (stateno=111&&time>0)
trigger2 = abs(Enemynear,pos X - pos X)=[30,70]
trigger2 = random<50
trigger3 = stateno = 1310 || stateno = 1330
trigger3 = time>0
trigger3 = p2bodydist X=[15,70]
trigger3 = Enemynear,animtime>=7

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = A
triggerall = Enemynear,statetype!=L
trigger1 = !inguarddist || (var(59)<=2 && random<50)
trigger1 = ctrl
trigger1 = p2bodydist X=[0,30]
trigger1 = p2bodydist Y=[-60,20]
trigger1 = random<333
trigger2 = !inguarddist || (var(59)<=2 && random<50)
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger2 = p2bodydist X=[0,30]
trigger2 = p2bodydist Y=[-10,10]
trigger3 = stateno = 1350 ;Air blocking
trigger3 = p2bodydist X=[0,15]

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = A
triggerall = !inguarddist
triggerall = Enemynear,statetype!=L
trigger1 = ctrl
trigger1 = p2bodydist X=[10,30]
trigger1 = p2bodydist Y=[-80,20]
trigger1 = random<100
trigger1 = vel Y - Enemynear,vel Y>=0
trigger2 = ctrl
trigger2 = stateno=105
trigger2 = Enemynear,hitdefattr=SCA,AT

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = A
trigger1 = !inguarddist
trigger1 = ctrl
trigger1 = p2bodydist X=[30,50]
trigger1 = random<50
trigger1 = Enemynear,statetype!=L
trigger2 = !inguarddist
trigger2 = ctrl
trigger2 = stateno=105
trigger2 = !inguarddist
trigger2 = Enemynear,movetype!=A
trigger2 = !Enemynear,hitdefattr=SCA,AP
trigger3 = stateno = 600 || stateno = 630
trigger3 = movecontact
trigger3 = Enemynear,statetype!=L
trigger4 = stateno = 1350 ;Air blocking
trigger4 = p2bodydist X=[0,30]

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 111
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = S
triggerall = ishelper || !inguarddist
triggerall = Enemynear,statetype!=L || (ishelper && p2bodydist X>20)
triggerall = frontedgebodydist>5
triggerall = ctrl
triggerall = var(59)>=2 || random<100
trigger1 = ishelper
trigger1 = p2bodydist X>0
trigger2 = !ishelper
trigger2 = p2bodydist X>10
trigger2 = Enemynear,movetype!=A
trigger3 = Enemynear,movetype=H
trigger3 = p2bodydist X>0

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
triggerall = var(59) && roundstate=2 && life>0
triggerall = ishelper || var(3)
triggerall = statetype = S
triggerall = !inguarddist || (var(59)<=2 && random<50)
triggerall = ctrl || (stateno=111&&time>0)
triggerall = backedgebodydist>5
triggerall = Enemynear,movetype!=H
trigger1 = ishelper
trigger1 = p2bodydist X<50
trigger1 = random<10
trigger2 = !ishelper
trigger2 = p2bodydist X<80
trigger2 = random<20
trigger3 = Enemynear,statetype=L
trigger4 = Enemynear,hitdefattr=SCA,AT
trigger5 = pos Y<=-10
trigger5 = random<333

;---------------------------------------------------------------------------
;オ
[State -1]
type = ChangeState
value = 12
trigger1 = !ishelper || ishelper(65531) || ishelper(65532) || ishelper(65533) || ishelper(65534)
trigger1 = var(59) && roundstate=2 && life>0
trigger1 = ishelper || var(3)
trigger1 = stateno=11
trigger1 = ctrl
trigger1 = statetype != A
